@@ -8,8 +8,8 @@ from typing import Any, Dict, List, Optional, Sequence
 
 import dataproperty as dp
 import typepy
+from dataproperty.typing import TypeHint
 from typepy import Nan
-from typepy.type import AbstractType
 
 from ._constant import PatternMatch
 from ._converter import to_value_matrix
@@ -31,7 +31,7 @@ class TableData:
         headers: Sequence[str],
         rows: Sequence,
         dp_extractor: Optional[dp.DataPropertyExtractor] = None,
-        type_hints: Optional[Sequence[AbstractType]] = None,
+        type_hints: Optional[Sequence[TypeHint]] = None,
         max_workers: Optional[int] = None,
     ):
         self.__table_name = table_name
@@ -429,7 +429,12 @@ class TableData:
         return dataframe
 
     def transpose(self):
-        return TableData(self.table_name, self.headers, [row for row in zip(*self.rows)])
+        return TableData(
+            self.table_name,
+            self.headers,
+            [row for row in zip(*self.rows)],
+            max_workers=self.max_workers,
+        )
 
     def filter_column(
         self,
@@ -477,10 +482,20 @@ class TableData:
             )
         )
 
-        return TableData(self.table_name, match_header_list, list(zip(*match_column_matrix)))
+        return TableData(
+            self.table_name,
+            match_header_list,
+            list(zip(*match_column_matrix)),
+            max_workers=self.max_workers,
+        )
 
     @staticmethod
-    def from_dataframe(dataframe, table_name: str = ""):
+    def from_dataframe(
+        dataframe,
+        table_name: str = "",
+        type_hints: Optional[Sequence[TypeHint]] = None,
+        max_workers: Optional[int] = None,
+    ):
         """
         Initialize TableData instance from a pandas.DataFrame instance.
 
@@ -488,7 +503,13 @@ class TableData:
         :param str table_name: Table name to create.
         """
 
-        return TableData(table_name, list(dataframe.columns.values), dataframe.values.tolist())
+        return TableData(
+            table_name,
+            list(dataframe.columns.values),
+            dataframe.values.tolist(),
+            type_hints=type_hints,
+            max_workers=max_workers,
+        )
 
     @staticmethod
     def __is_match(header: str, pattern: str, is_re_match: bool) -> bool:
